within ;
package MOSCviceniBuildings2
  package BaseClasses
    extends Modelica.Icons.BasesPackage;
    model DumBezTopeni "Tepelne hospodareni domu"

    //  replaceable package MediumA =
      //    Buildings.Media.GasesPTDecoupled.MoistAirUnsaturated;
      replaceable package MediumA =
          Buildings.Media.GasesPTDecoupled.MoistAirUnsaturated;

      parameter Modelica.SIunits.Volume V = 6*10*3 "Objem pokoje";
      parameter Modelica.SIunits.MassFlowRate maflownominal = V * 6/3600;
      Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature venkovniTeplota
        annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));
      Modelica.Thermal.HeatTransfer.Components.ThermalConductor ztratyTepla(G=143)
                annotation (Placement(transformation(extent={{-48,-10},{-28,10}})));
      Modelica.Thermal.HeatTransfer.Components.HeatCapacitor kapacitaNabytku(C=2*V*1.2
            *1006) "tepelna kapacita nabytku a sten"
        annotation (Placement(transformation(extent={{18,-56},{38,-36}})));
      Buildings.Fluid.MixingVolumes.MixingVolume vzduch(
      redeclare package Medium = MediumA,
      m_flow_nominal=
            maflownominal,
        V=V) "tepelne smiseny vzduch"
        annotation (Placement(transformation(extent={{14,-10},{34,10}})));
      Modelica.Blocks.Interfaces.RealInput outT
        annotation (Placement(transformation(extent={{-110,20},{-70,60}}),
            iconTransformation(extent={{-80,-20},{-40,20}})));
    equation
      connect(venkovniTeplota.port, ztratyTepla.port_a) annotation (Line(
          points={{-60,0},{-48,0}},
          color={191,0,0},
          smooth=Smooth.None));
      connect(kapacitaNabytku.port, ztratyTepla.port_b) annotation (Line(
          points={{28,-56},{-2,-56},{-2,0},{-28,0}},
          color={191,0,0},
          smooth=Smooth.None));
      connect(vzduch.heatPort, ztratyTepla.port_b) annotation (Line(
          points={{14,0},{-28,0}},
          color={191,0,0},
          smooth=Smooth.None));
      connect(venkovniTeplota.T, outT) annotation (Line(
          points={{-82,0},{-84,0},{-84,40},{-90,40}},
          color={0,0,127},
          smooth=Smooth.None));
      annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                -100},{100,100}}), graphics={Rectangle(
              extent={{-40,60},{40,-60}},
              lineColor={0,0,255},
              fillPattern=FillPattern.Solid,
              fillColor={255,255,170}), Polygon(
              points={{-60,60},{0,100},{60,60},{-60,60}},
              lineColor={0,0,255},
              smooth=Smooth.None,
              fillPattern=FillPattern.Solid,
              fillColor={255,170,170})}), Icon(coordinateSystem(preserveAspectRatio=false,
                      extent={{-100,-100},{100,100}}), graphics={
                                        Polygon(
              points={{-60,60},{0,100},{60,60},{-60,60}},
              lineColor={0,0,255},
              smooth=Smooth.None,
              fillPattern=FillPattern.Solid,
              fillColor={255,170,170}),      Rectangle(
              extent={{-40,60},{40,-60}},
              lineColor={0,0,255},
              fillPattern=FillPattern.Solid,
              fillColor={255,255,170}),
            Text(
              extent={{-234,-62},{230,-100}},
              lineColor={0,0,255},
              textString="%name")}));
    end DumBezTopeni;

    model DumSeSporakem
      extends DumBezTopeni;
      Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow sporak
        annotation (Placement(transformation(extent={{-14,26},{6,46}})));
      Modelica.Blocks.Sources.Pulse pulse(
        period(displayUnit="d") = 86400,
        startTime(displayUnit="h") = 36000,
        width=17,
        amplitude=4000)
        annotation (Placement(transformation(extent={{-50,26},{-30,46}})));
    equation
      connect(sporak.port, ztratyTepla.port_b) annotation (Line(
          points={{6,36},{6,0},{-28,0}},
          color={191,0,0},
          smooth=Smooth.None));
      connect(pulse.y, sporak.Q_flow) annotation (Line(
          points={{-29,36},{-14,36}},
          color={0,0,127},
          smooth=Smooth.None));
      annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{
                -100,-100},{100,100}}), graphics));
    end DumSeSporakem;

    model DumSRadiatorem
      extends DumSeSporakem;
      replaceable package MediumW =
          Buildings.Media.ConstantPropertyLiquidWater "Medium model";
      Buildings.Fluid.HeatExchangers.Radiators.RadiatorEN442_2 rad(
      redeclare package Medium = MediumW,
        Q_flow_nominal(displayUnit="kW") = 20000,
        energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial,
        T_a_nominal=323.15,
        T_b_nominal=313.15)
        annotation (Placement(transformation(extent={{-36,-50},{-16,-30}})));
      Buildings.Fluid.Sources.FixedBoundary teplaVoda(  redeclare package
          Medium =                                                                 MediumW,
      nPorts=1,
        T=323.15)
                annotation (
          Placement(transformation(
            extent={{-10,-10},{10,10}},
            rotation=90,
            origin={-46,-76})));
      Buildings.Fluid.Sources.FixedBoundary ochlazenaVoda(  redeclare package
          Medium =                                                                     MediumW, nPorts=1) annotation (
          Placement(transformation(
            extent={{-10,-10},{10,10}},
            rotation=90,
            origin={-10,-72})));
      Buildings.Fluid.Movers.FlowControlled_m_flow fan(redeclare package Medium
          = MediumW, m_flow_nominal=0.47)              annotation (Placement(
            transformation(
            extent={{-10,-10},{10,10}},
            rotation=90,
            origin={-44,-50})));
      Modelica.Blocks.Sources.Pulse pulse1(
        amplitude=0.47,
        width=50,
        period(displayUnit="h") = 3600,
        startTime(displayUnit="h") = 0)
        annotation (Placement(transformation(extent={{-86,-60},{-66,-40}})));
    equation
      connect(rad.heatPortRad, ztratyTepla.port_b) annotation (Line(
          points={{-24,-32.8},{-22,-32.8},{-22,-26},{-2,-26},{-2,0},{-28,0}},
          color={191,0,0},
          smooth=Smooth.None));
      connect(rad.heatPortCon, ztratyTepla.port_b) annotation (Line(
          points={{-28,-32.8},{-28,-22},{-2,-22},{-2,0},{-28,0}},
          color={191,0,0},
          smooth=Smooth.None));
      connect(ochlazenaVoda.ports[1], rad.port_b) annotation (Line(
          points={{-10,-62},{-10,-40},{-16,-40}},
          color={0,127,255},
          smooth=Smooth.None));
      connect(teplaVoda.ports[1], fan.port_a) annotation (Line(
          points={{-46,-66},{-46,-60},{-44,-60}},
          color={0,127,255},
          smooth=Smooth.None));
      connect(fan.port_b, rad.port_a) annotation (Line(
          points={{-44,-40},{-36,-40}},
          color={0,127,255},
          smooth=Smooth.None));
      connect(pulse1.y, fan.m_flow_in) annotation (Line(
          points={{-65,-50},{-66,-50},{-66,-50.2},{-56,-50.2}},
          color={0,0,127},
          smooth=Smooth.None));
      annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                -100},{100,100}}), graphics));
    end DumSRadiatorem;
  end BaseClasses;

  model SimulaceTeplaDomu
    extends Modelica.Icons.Example;
    Modelica.Blocks.Sources.Sine sine(
      amplitude=5,
      freqHz(displayUnit="1/d") = 1.1574074074074e-05,
      offset=263)
      annotation (Placement(transformation(extent={{-46,-10},{-26,10}})));
    BaseClasses.DumBezTopeni dumBezTopeni
      annotation (Placement(transformation(extent={{0,-10},{20,10}})));
  equation
    connect(sine.y, dumBezTopeni.outT) annotation (Line(
        points={{-25,0},{4,0}},
        color={0,0,127},
        smooth=Smooth.None));
    annotation (
      Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
              100,100}}), graphics),
      experiment(StopTime=172800, __Dymola_NumberOfIntervals=5000),
      __Dymola_experimentSetupOutput);
  end SimulaceTeplaDomu;
  annotation (uses(Modelica(version="3.2.1"), Buildings(version="1.7")));
end MOSCviceniBuildings2;
